@@ -4,15 +4,18 @@
 
 These are largely borrowed from Django's `contrib.humanize`.
 """
+from __future__ import annotations
 
+import collections.abc
 import datetime as dt
 import math
-import warnings
-from enum import Enum, EnumMeta
+import typing
+from enum import Enum
 from functools import total_ordering
 
 from .i18n import _gettext as _
 from .i18n import _ngettext
+from .number import intcomma
 
 __all__ = [
     "naturaldelta",
@@ -24,7 +27,7 @@ __all__ = [
 
 
 @total_ordering
-class _Unit(Enum):
+class Unit(Enum):
     MICROSECONDS = 0
     MILLISECONDS = 1
     SECONDS = 2
@@ -34,55 +37,17 @@ class _Unit(Enum):
     MONTHS = 6
     YEARS = 7
 
-    def __lt__(self, other):
+    def __lt__(self, other: typing.Any) -> typing.Any:
         if self.__class__ is other.__class__:
             return self.value < other.value
         return NotImplemented
 
 
-class _UnitMeta(EnumMeta):
-    """Metaclass for an enum that emits deprecation warnings when accessed."""
-
-    def __getattribute__(self, name):
-        # Temporarily comment out to avoid warning during 'import humanize'
-        # warnings.warn(
-        #     "`Unit` has been deprecated. "
-        #     "The enum is still available as the private member `_Unit`.",
-        #     DeprecationWarning,
-        # )
-        return EnumMeta.__getattribute__(_Unit, name)
-
-    def __getitem__(cls, name):
-        warnings.warn(
-            "`Unit` has been deprecated. "
-            "The enum is still available as the private member `_Unit`.",
-            DeprecationWarning,
-        )
-        return _Unit.__getitem__(name)
-
-    def __call__(
-        cls, value, names=None, *, module=None, qualname=None, type=None, start=1
-    ):
-        warnings.warn(
-            "`Unit` has been deprecated. "
-            "The enum is still available as the private member `_Unit`.",
-            DeprecationWarning,
-        )
-        return _Unit.__call__(
-            value, names, module=module, qualname=qualname, type=type, start=start
-        )
-
-
-class Unit(Enum, metaclass=_UnitMeta):
-    # Temporary alias for _Unit to allow backwards-compatible usage.
-    pass
-
-
-def _now():
+def _now() -> dt.datetime:
     return dt.datetime.now()
 
 
-def _abs_timedelta(delta):
+def _abs_timedelta(delta: dt.timedelta) -> dt.timedelta:
     """Return an "absolute" value for a timedelta, always representing a time distance.
 
     Args:
@@ -97,27 +62,9 @@ def _abs_timedelta(delta):
     return delta
 
 
-def abs_timedelta(delta):
-    """Return an "absolute" value for a timedelta, always representing a time distance.
-
-    Args:
-        delta (datetime.timedelta): Input timedelta.
-
-    Returns:
-        datetime.timedelta: Absolute timedelta.
-
-    WARNING: This function has been deprecated. It is still available as the private
-    member `_abs_timedelta`.
-    """
-    warnings.warn(
-        "`abs_timedelta` has been deprecated. "
-        "It is still available as the private member `_abs_timedelta`.",
-        DeprecationWarning,
-    )
-    return _abs_timedelta(delta)
-
-
-def _date_and_delta(value, *, now=None):
+def _date_and_delta(
+    value: typing.Any, *, now: dt.datetime | None = None
+) -> tuple[typing.Any, typing.Any]:
     """Turn a value into a date and a timedelta which represents how long ago it was.
 
     If that's not possible, return `(None, value)`.
@@ -140,42 +87,28 @@ def _date_and_delta(value, *, now=None):
     return date, _abs_timedelta(delta)
 
 
-def date_and_delta(delta):
-    """Turn a value into a date and a timedelta which represents how long ago it was.
-
-    If that's not possible, return `(None, value)`.
-
-    WARNING: This function has been deprecated. It is still available as the private
-    member `_date_and_delta`.
-    """
-    warnings.warn(
-        "`date_and_delta` has been deprecated. "
-        "It is still available as the private member `_date_and_delta`.",
-        DeprecationWarning,
-    )
-    return _date_and_delta(delta)
-
-
 def naturaldelta(
-    value,
-    months=True,
-    minimum_unit="seconds",
-    when=None,
+    value: dt.timedelta | int,
+    months: bool = True,
+    minimum_unit: str = "seconds",
 ) -> str:
     """Return a natural representation of a timedelta or number of seconds.
 
     This is similar to `naturaltime`, but does not add tense to the result.
 
     Args:
-        value (datetime.timedelta): A timedelta or a number of seconds.
+        value (datetime.timedelta or int): A timedelta or a number of seconds.
         months (bool): If `True`, then a number of months (based on 30.5 days) will be
             used for fuzziness between years.
         minimum_unit (str): The lowest unit that can be used.
-        when (datetime.datetime): Point in time relative to which _value_ is
-            interpreted.  Defaults to the current time in the local timezone.
 
     Returns:
-        str: A natural representation of the amount of time elapsed.
+        str (str or `value`): A natural representation of the amount of time
+            elapsed unless `value` is not datetime.timedelta or cannot be
+            converted to int. In that case, a `value` is returned unchanged.
+
+    Raises:
+        OverflowError: If `value` is too large to convert to datetime.timedelta.
 
     Examples
         Compare two timestamps in a custom local timezone::
@@ -187,16 +120,21 @@ def naturaldelta(
         now = dt.datetime.now(tz=berlin)
         later = now + dt.timedelta(minutes=30)
 
-        assert naturaldelta(later, when=now) == "30 minutes"
+        assert naturaldelta(later - now) == "30 minutes"
     """
-    tmp = _Unit[minimum_unit.upper()]
-    if tmp not in (_Unit.SECONDS, _Unit.MILLISECONDS, _Unit.MICROSECONDS):
+    tmp = Unit[minimum_unit.upper()]
+    if tmp not in (Unit.SECONDS, Unit.MILLISECONDS, Unit.MICROSECONDS):
         raise ValueError(f"Minimum unit '{minimum_unit}' not supported")
-    minimum_unit = tmp
+    min_unit = tmp
 
-    date, delta = _date_and_delta(value, now=when)
-    if date is None:
-        return value
+    if isinstance(value, dt.timedelta):
+        delta = value
+    else:
+        try:
+            value = int(value)
+            delta = dt.timedelta(seconds=value)
+        except (ValueError, TypeError):
+            return str(value)
 
     use_months = months
 
@@ -204,22 +142,21 @@ def naturaldelta(
     days = abs(delta.days)
     years = days // 365
     days = days % 365
-    months = int(days // 30.5)
+    num_months = int(days // 30.5)
 
     if not years and days < 1:
         if seconds == 0:
-            if minimum_unit == _Unit.MICROSECONDS and delta.microseconds < 1000:
+            if min_unit == Unit.MICROSECONDS and delta.microseconds < 1000:
                 return (
                     _ngettext("%d microsecond", "%d microseconds", delta.microseconds)
                     % delta.microseconds
                 )
-            elif minimum_unit == _Unit.MILLISECONDS or (
-                minimum_unit == _Unit.MICROSECONDS
-                and 1000 <= delta.microseconds < 1_000_000
+            elif min_unit == Unit.MILLISECONDS or (
+                min_unit == Unit.MICROSECONDS and 1000 <= delta.microseconds < 1_000_000
             ):
                 milliseconds = delta.microseconds / 1000
                 return (
-                    _ngettext("%d millisecond", "%d milliseconds", milliseconds)
+                    _ngettext("%d millisecond", "%d milliseconds", int(milliseconds))
                     % milliseconds
                 )
             return _("a moment")
@@ -243,36 +180,37 @@ def naturaldelta(
         if not use_months:
             return _ngettext("%d day", "%d days", days) % days
         else:
-            if not months:
+            if not num_months:
                 return _ngettext("%d day", "%d days", days) % days
-            elif months == 1:
+            elif num_months == 1:
                 return _("a month")
             else:
-                return _ngettext("%d month", "%d months", months) % months
+                return _ngettext("%d month", "%d months", num_months) % num_months
     elif years == 1:
-        if not months and not days:
+        if not num_months and not days:
             return _("a year")
-        elif not months:
+        elif not num_months:
             return _ngettext("1 year, %d day", "1 year, %d days", days) % days
         elif use_months:
-            if months == 1:
+            if num_months == 1:
                 return _("1 year, 1 month")
             else:
                 return (
-                    _ngettext("1 year, %d month", "1 year, %d months", months) % months
+                    _ngettext("1 year, %d month", "1 year, %d months", num_months)
+                    % num_months
                 )
         else:
             return _ngettext("1 year, %d day", "1 year, %d days", days) % days
-    else:
-        return _ngettext("%d year", "%d years", years) % years
+
+    return _ngettext("%s year", "%s years", years) % intcomma(years)
 
 
 def naturaltime(
-    value,
-    future=False,
-    months=True,
-    minimum_unit="seconds",
-    when=None,
+    value: dt.datetime | int,
+    future: bool = False,
+    months: bool = True,
+    minimum_unit: str = "seconds",
+    when: dt.datetime | None = None,
 ) -> str:
     """Return a natural representation of a time in a resolution that makes sense.
 
@@ -295,21 +233,21 @@ def naturaltime(
     now = when or _now()
     date, delta = _date_and_delta(value, now=now)
     if date is None:
-        return value
+        return str(value)
     # determine tense by value only if datetime/timedelta were passed
     if isinstance(value, (dt.datetime, dt.timedelta)):
         future = date > now
 
     ago = _("%s from now") if future else _("%s ago")
-    delta = naturaldelta(delta, months, minimum_unit, when=when)
+    delta = naturaldelta(delta, months, minimum_unit)
 
     if delta == _("a moment"):
         return _("now")
 
-    return ago % delta
+    return str(ago % delta)
 
 
-def naturalday(value, format="%b %d") -> str:
+def naturalday(value: dt.date | dt.datetime, format: str = "%b %d") -> str:
     """Return a natural day.
 
     For date values that are tomorrow, today or yesterday compared to
@@ -321,10 +259,10 @@ def naturalday(value, format="%b %d") -> str:
         value = dt.date(value.year, value.month, value.day)
     except AttributeError:
         # Passed value wasn't date-ish
-        return value
+        return str(value)
     except (OverflowError, ValueError):
         # Date arguments out of range
-        return value
+        return str(value)
     delta = value - dt.date.today()
     if delta.days == 0:
         return _("today")
@@ -335,23 +273,29 @@ def naturalday(value, format="%b %d") -> str:
     return value.strftime(format)
 
 
-def naturaldate(value) -> str:
+def naturaldate(value: dt.date | dt.datetime) -> str:
     """Like `naturalday`, but append a year for dates more than ~five months away."""
     try:
         value = dt.date(value.year, value.month, value.day)
     except AttributeError:
         # Passed value wasn't date-ish
-        return value
+        return str(value)
     except (OverflowError, ValueError):
         # Date arguments out of range
-        return value
+        return str(value)
     delta = _abs_timedelta(value - dt.date.today())
     if delta.days >= 5 * 365 / 12:
         return naturalday(value, "%b %d %Y")
     return naturalday(value)
 
 
-def _quotient_and_remainder(value, divisor, unit, minimum_unit, suppress):
+def _quotient_and_remainder(
+    value: float,
+    divisor: float,
+    unit: Unit,
+    minimum_unit: Unit,
+    suppress: collections.abc.Iterable[Unit],
+) -> tuple[float, float]:
     """Divide `value` by `divisor` returning the quotient and remainder.
 
     If `unit` is `minimum_unit`, makes the quotient a float number and the remainder
@@ -359,82 +303,89 @@ def _quotient_and_remainder(value, divisor, unit, minimum_unit, suppress):
     represent the remainder because it would require a unit smaller than the
     `minimum_unit`.
 
-    >>> from humanize.time import _quotient_and_remainder, _Unit
-    >>> _quotient_and_remainder(36, 24, _Unit.DAYS, _Unit.DAYS, [])
+    >>> from humanize.time import _quotient_and_remainder, Unit
+    >>> _quotient_and_remainder(36, 24, Unit.DAYS, Unit.DAYS, [])
     (1.5, 0)
 
     If unit is in `suppress`, the quotient will be zero and the remainder will be the
     initial value. The idea is that if we cannot use `unit`, we are forced to use a
     lower unit so we cannot do the division.
 
-    >>> _quotient_and_remainder(36, 24, _Unit.DAYS, _Unit.HOURS, [_Unit.DAYS])
+    >>> _quotient_and_remainder(36, 24, Unit.DAYS, Unit.HOURS, [Unit.DAYS])
     (0, 36)
 
     In other case return quotient and remainder as `divmod` would do it.
 
-    >>> _quotient_and_remainder(36, 24, _Unit.DAYS, _Unit.HOURS, [])
+    >>> _quotient_and_remainder(36, 24, Unit.DAYS, Unit.HOURS, [])
     (1, 12)
 
     """
     if unit == minimum_unit:
-        return (value / divisor, 0)
+        return value / divisor, 0
     elif unit in suppress:
-        return (0, value)
+        return 0, value
     else:
         return divmod(value, divisor)
 
 
-def _carry(value1, value2, ratio, unit, min_unit, suppress):
+def _carry(
+    value1: float,
+    value2: float,
+    ratio: float,
+    unit: Unit,
+    min_unit: Unit,
+    suppress: typing.Iterable[Unit],
+) -> tuple[float, float]:
     """Return a tuple with two values.
 
     If the unit is in `suppress`, multiply `value1` by `ratio` and add it to `value2`
     (carry to right). The idea is that if we cannot represent `value1` we need to
     represent it in a lower unit.
 
-    >>> from humanize.time import _carry, _Unit
-    >>> _carry(2, 6, 24, _Unit.DAYS, _Unit.SECONDS, [_Unit.DAYS])
+    >>> from humanize.time import _carry, Unit
+    >>> _carry(2, 6, 24, Unit.DAYS, Unit.SECONDS, [Unit.DAYS])
     (0, 54)
 
     If the unit is the minimum unit, `value2` is divided by `ratio` and added to
     `value1` (carry to left). We assume that `value2` has a lower unit so we need to
     carry it to `value1`.
 
-    >>> _carry(2, 6, 24, _Unit.DAYS, _Unit.DAYS, [])
+    >>> _carry(2, 6, 24, Unit.DAYS, Unit.DAYS, [])
     (2.25, 0)
 
     Otherwise, just return the same input:
 
-    >>> _carry(2, 6, 24, _Unit.DAYS, _Unit.SECONDS, [])
+    >>> _carry(2, 6, 24, Unit.DAYS, Unit.SECONDS, [])
     (2, 6)
     """
     if unit == min_unit:
-        return (value1 + value2 / ratio, 0)
+        return value1 + value2 / ratio, 0
     elif unit in suppress:
-        return (0, value2 + value1 * ratio)
+        return 0, value2 + value1 * ratio
     else:
-        return (value1, value2)
+        return value1, value2
 
 
-def _suitable_minimum_unit(min_unit, suppress):
+def _suitable_minimum_unit(min_unit: Unit, suppress: typing.Iterable[Unit]) -> Unit:
     """Return a minimum unit suitable that is not suppressed.
 
     If not suppressed, return the same unit:
 
-    >>> from humanize.time import _suitable_minimum_unit, _Unit
-    >>> _suitable_minimum_unit(_Unit.HOURS, []).name
+    >>> from humanize.time import _suitable_minimum_unit, Unit
+    >>> _suitable_minimum_unit(Unit.HOURS, []).name
     'HOURS'
 
     But if suppressed, find a unit greather than the original one that is not
     suppressed:
 
-    >>> _suitable_minimum_unit(_Unit.HOURS, [_Unit.HOURS]).name
+    >>> _suitable_minimum_unit(Unit.HOURS, [Unit.HOURS]).name
     'DAYS'
 
-    >>> _suitable_minimum_unit(_Unit.HOURS, [_Unit.HOURS, _Unit.DAYS]).name
+    >>> _suitable_minimum_unit(Unit.HOURS, [Unit.HOURS, Unit.DAYS]).name
     'MONTHS'
     """
     if min_unit in suppress:
-        for unit in _Unit:
+        for unit in Unit:
             if unit > min_unit and unit not in suppress:
                 return unit
 
@@ -445,15 +396,15 @@ def _suitable_minimum_unit(min_unit, suppress):
     return min_unit
 
 
-def _suppress_lower_units(min_unit, suppress):
+def _suppress_lower_units(min_unit: Unit, suppress: typing.Iterable[Unit]) -> set[Unit]:
     """Extend suppressed units (if any) with all units lower than the minimum unit.
 
-    >>> from humanize.time import _suppress_lower_units, _Unit
-    >>> [x.name for x in sorted(_suppress_lower_units(_Unit.SECONDS, [_Unit.DAYS]))]
+    >>> from humanize.time import _suppress_lower_units, Unit
+    >>> [x.name for x in sorted(_suppress_lower_units(Unit.SECONDS, [Unit.DAYS]))]
     ['MICROSECONDS', 'MILLISECONDS', 'DAYS']
     """
     suppress = set(suppress)
-    for u in _Unit:
+    for u in Unit:
         if u == min_unit:
             break
         suppress.add(u)
@@ -461,7 +412,12 @@ def _suppress_lower_units(min_unit, suppress):
     return suppress
 
 
-def precisedelta(value, minimum_unit="seconds", suppress=(), format="%0.2f") -> str:
+def precisedelta(
+    value: dt.timedelta | int,
+    minimum_unit: str = "seconds",
+    suppress: typing.Iterable[str] = (),
+    format: str = "%0.2f",
+) -> str:
     """Return a precise representation of a timedelta.
 
     ```pycon
@@ -530,19 +486,19 @@ def precisedelta(value, minimum_unit="seconds", suppress=(), format="%0.2f") ->
     """
     date, delta = _date_and_delta(value)
     if date is None:
-        return value
+        return str(value)
 
-    suppress = [_Unit[s.upper()] for s in suppress]
+    suppress_set = {Unit[s.upper()] for s in suppress}
 
     # Find a suitable minimum unit (it can be greater the one that the
     # user gave us if it is suppressed).
-    min_unit = _Unit[minimum_unit.upper()]
-    min_unit = _suitable_minimum_unit(min_unit, suppress)
+    min_unit = Unit[minimum_unit.upper()]
+    min_unit = _suitable_minimum_unit(min_unit, suppress_set)
     del minimum_unit
 
     # Expand the suppressed units list/set to include all the units
     # that are below the minimum unit
-    suppress = _suppress_lower_units(min_unit, suppress)
+    suppress_set = _suppress_lower_units(min_unit, suppress_set)
 
     # handy aliases
     days = delta.days
@@ -550,7 +506,7 @@ def precisedelta(value, minimum_unit="seconds", suppress=(), format="%0.2f") ->
     usecs = delta.microseconds
 
     MICROSECONDS, MILLISECONDS, SECONDS, MINUTES, HOURS, DAYS, MONTHS, YEARS = list(
-        _Unit
+        Unit
     )
 
     # Given DAYS compute YEARS and the remainder of DAYS as follows:
@@ -565,27 +521,27 @@ def precisedelta(value, minimum_unit="seconds", suppress=(), format="%0.2f") ->
     #       years, days = divmod(years, days)
     #
     # The same applies for months, hours, minutes and milliseconds below
-    years, days = _quotient_and_remainder(days, 365, YEARS, min_unit, suppress)
-    months, days = _quotient_and_remainder(days, 30.5, MONTHS, min_unit, suppress)
+    years, days = _quotient_and_remainder(days, 365, YEARS, min_unit, suppress_set)
+    months, days = _quotient_and_remainder(days, 30.5, MONTHS, min_unit, suppress_set)
 
     # If DAYS is not in suppress, we can represent the days but
     # if it is a suppressed unit, we need to carry it to a lower unit,
     # seconds in this case.
     #
     # The same applies for secs and usecs below
-    days, secs = _carry(days, secs, 24 * 3600, DAYS, min_unit, suppress)
+    days, secs = _carry(days, secs, 24 * 3600, DAYS, min_unit, suppress_set)
 
-    hours, secs = _quotient_and_remainder(secs, 3600, HOURS, min_unit, suppress)
-    minutes, secs = _quotient_and_remainder(secs, 60, MINUTES, min_unit, suppress)
+    hours, secs = _quotient_and_remainder(secs, 3600, HOURS, min_unit, suppress_set)
+    minutes, secs = _quotient_and_remainder(secs, 60, MINUTES, min_unit, suppress_set)
 
-    secs, usecs = _carry(secs, usecs, 1e6, SECONDS, min_unit, suppress)
+    secs, usecs = _carry(secs, usecs, 1e6, SECONDS, min_unit, suppress_set)
 
     msecs, usecs = _quotient_and_remainder(
-        usecs, 1000, MILLISECONDS, min_unit, suppress
+        usecs, 1000, MILLISECONDS, min_unit, suppress_set
     )
 
     # if _unused != 0 we had lost some precision
-    usecs, _unused = _carry(usecs, 0, 1, MICROSECONDS, min_unit, suppress)
+    usecs, _unused = _carry(usecs, 0, 1, MICROSECONDS, min_unit, suppress_set)
 
     fmts = [
         ("%d year", "%d years", years),
@@ -598,15 +554,19 @@ def precisedelta(value, minimum_unit="seconds", suppress=(), format="%0.2f") ->
         ("%d microsecond", "%d microseconds", usecs),
     ]
 
-    texts = []
-    for unit, fmt in zip(reversed(_Unit), fmts):
-        singular_txt, plural_txt, value = fmt
-        if value > 0 or (not texts and unit == min_unit):
-            fmt_txt = _ngettext(singular_txt, plural_txt, value)
-            if unit == min_unit and math.modf(value)[0] > 0:
+    texts: list[str] = []
+    for unit, fmt in zip(reversed(Unit), fmts):
+        singular_txt, plural_txt, fmt_value = fmt
+        if fmt_value > 0 or (not texts and unit == min_unit):
+            fmt_txt = _ngettext(singular_txt, plural_txt, fmt_value)
+            if unit == min_unit and math.modf(fmt_value)[0] > 0:
                 fmt_txt = fmt_txt.replace("%d", format)
+            elif unit == YEARS:
+                fmt_txt = fmt_txt.replace("%d", "%s")
+                texts.append(fmt_txt % intcomma(fmt_value))
+                continue
 
-            texts.append(fmt_txt % value)
+            texts.append(fmt_txt % fmt_value)
 
         if unit == min_unit:
             break
